# Detect the distribution in use
%global __despace head -n 1 | tr -d '[:space:]' | sed -e 's/[(].*[)]//g'
%global __lower4 cut -c 1-4 | tr '[:upper:]' '[:lower:]'
%global __distfile %([ -f /etc/SuSE-release ] && echo /etc/SuSE-release || echo /etc/redhat-release)
%global __distinit %(sed -e 's/ release .*//' -e 's/\\([A-Za-z]\\)[^ ]*/\\1/g' %{__distfile} | %{__despace} | %{__lower4})
%global __distvers %(sed -e 's/.* release \\([^. ]*\\).*/\\1/' %{__distfile} | %{__despace})
# Identify Alma, CentOS, CentOS Stream and Rocky Linux as rhel
%if "%{__distinit}" == "a" || "%{__distinit}" == "c" || "%{__distinit}" == "cl" || "%{__distinit}" == "cs" || "%{__distinit}" == "rl"
%global __distinit rhel
%endif
# Dist tag for Fedora is still "fc"
%if "%{__distinit}" == "f"
%global __distinit fc
%endif

# At some point, enable Test::Stream support by conditionally pulling
# in Test::Stream and Test::Stream::Event::Ok in sufficiently recent dists

# noarch, but to avoid debug* files interfering with manifest test:
%global debug_package %{nil}

Name:		perl-Test-Exception
Version:	0.43
Release:	23.%{__distinit}%{__distvers}
Summary:	Library of test functions for exception based Perl code
License:	GPL-1.0-or-later OR Artistic-1.0-Perl
URL:		https://metacpan.org/release/Test-Exception
Source0:	https://cpan.metacpan.org/modules/by-module/Test/Test-Exception-%{version}.tar.gz
Patch0:		Test-Exception-0.38-spelling.patch
Patch1:		Test-Exception-0.43-critic.patch
BuildArch:	noarch
# Module Build
BuildRequires:	coreutils
BuildRequires:	findutils
BuildRequires:	make
BuildRequires:	perl-generators
BuildRequires:	perl-interpreter
BuildRequires:	perl(ExtUtils::MakeMaker)
# Module Runtime
BuildRequires:	perl(base)
BuildRequires:	perl(Carp)
BuildRequires:	perl(Exporter)
BuildRequires:	perl(strict)
BuildRequires:	perl(Sub::Uplevel) >= 0.18
BuildRequires:	perl(Test::Builder)
BuildRequires:	perl(warnings)
# Test Suite
BuildRequires:	perl(overload)
BuildRequires:	perl(Test::Builder::Tester)
BuildRequires:	perl(Test::Harness)
BuildRequires:	perl(Test::More)
# Extra Tests
%if 0%{!?perl_bootstrap:1}
BuildRequires:	perl(Pod::Wordlist)
BuildRequires:	perl(Test::DistManifest)
BuildRequires:	perl(Test::Perl::Critic)
BuildRequires:	perl(Test::Pod) >= 1.00
BuildRequires:	perl(Test::Pod::Coverage) >= 1.00
BuildRequires:	perl(Test::Spelling), hunspell-en
%endif
# Dependencies
%if 0%{?fedora} < 38 && 0%{?rhel} < 10
Requires:	perl(:MODULE_COMPAT_%(eval "`perl -V:version`"; echo $version))
%endif
Requires:	perl(Carp)

# Remove bogus perl(DB) provide
%global __provides_exclude ^perl\\(DB\\)$

%description
This module provides a few convenience methods for testing exception
based code. It is built with Test::Builder and plays happily with
Test::More and friends.

%prep
%setup -q -n Test-Exception-%{version}

# Remove unnecessary exec permission
chmod -c -x Changes

# Fix typo and spelling test
%patch -P 0

# Fix perlcritic violation
%patch -P 1

%build
perl Makefile.PL INSTALLDIRS=vendor
make %{?_smp_mflags}

%install
make pure_install DESTDIR=%{buildroot}
find %{buildroot} -type f -name .packlist -delete
%{_fixperms} -c %{buildroot}

%check
make test
%if 0%{!?perl_bootstrap:1}
MANIFEST_WARN_ONLY=1 make test TEST_FILES="$(echo xt/*.t)"
%endif

%files
%doc Changes
%{perl_vendorlib}/Test/
%{_mandir}/man3/Test::Exception.3*

%changelog
* Mon May 15 2023 Paul Howarth <paul@city-fan.org> - 0.43-23
- Spec tidy-up
  - Use SPDX-format license tag
  - Avoid use of deprecated patch syntax
  - Drop support for building with rpm < 4.9

* Fri May 31 2019 Paul Howarth <paul@city-fan.org> - 0.43-11
- Perl 5.30 rebuild

* Tue Apr 10 2018 Paul Howarth <paul@city-fan.org> - 0.43-7
- BR: perl-generators unconditionally
- BR: perl-interpreter rather than perl
- Drop support for EOL distributions prior to F-13
  - Drop BuildRoot: and Group: tags
  - Drop explicit buildroot cleaning in %%install section
  - Drop explicit %%clean section
  - Always use hunspell for spell checking

* Tue Jul 26 2016 Paul Howarth <paul@city-fan.org> - 0.43-3
- Fix FTBFS when perl is not in the minimal buildroot
- Simplify find command using -delete
- BR: perl-generators where available

* Fri Jan  1 2016 Paul Howarth <paul@city-fan.org> - 0.43-1
- Update to 0.43
  - Remove Test2/Test-Stream special cases; they are not needed

* Tue Dec 22 2015 Paul Howarth <paul@city-fan.org> - 0.41-1
- Update to 0.41
  - Updated for Test2

* Sat Jun 13 2015 Paul Howarth <paul@city-fan.org> - 0.40-1
- Update to 0.40
  - Updated for changes in Test::Stream (use Test::Stream::Sync)
- This release by EXODIST → update source URL
- Set MANIFEST_WARN_ONLY=1 for the extra tests, as Test::DistManifest doesn't
  seem to be registering #!include_default in MANIFEST.SKIP

* Sun Mar  1 2015 Paul Howarth <paul@city-fan.org> - 0.38-1
- Update to 0.38
  - Distribution is now managed by ExtUtils::MakeMaker (CPAN RT#102054)
  - Fixed repository link in metadata
- This release by ETHER → update source URL
- Update spelling patch
- Reinstate the critic test

* Fri Jan  9 2015 Paul Howarth <paul@city-fan.org> - 0.36-1
- Update to 0.36
  - Fix bug when Test::More has been downgraded

* Tue Sep 23 2014 Paul Howarth <paul@city-fan.org> - 0.35-1
- Update to 0.35
  - Fix a bug when Test::Builder isn't new (better version)
- Switch to ExtUtils::MakeMaker flow
- Classify buildreqs by usage
- Filter bogus provide of perl(DB)

* Sat Sep 20 2014 Paul Howarth <paul@city-fan.org> - 0.34-1
- Update to 0.34
  - Fixed test broken by changes in Test::Builder and friends
- This release by EXODIST → update source URL
- Avoid the problematic Critic test for now

* Tue Sep  2 2014 Paul Howarth <paul@city-fan.org> - 0.32-5
- Drop %%defattr, redundant since rpm 4.4

* Mon Jul 22 2013 Paul Howarth <paul@city-fan.org> - 0.32-2
- Perl 5.18 rebuild

* Mon Apr 29 2013 Paul Howarth <paul@city-fan.org> - 0.32-1
- Update to 0.32:
  - Fixed tests that broke due to diagnostic changes in Test::More 0.99
- Update spelling patch

* Sun Jul  8 2012 Paul Howarth <paul@city-fan.org> - 0.31-6
- BR: perl(base), perl(Carp), perl(Exporter) and perl(Test::Harness)
- BR: perl(File::Which), perl(Test::Perl::Critic), perl(Test::Pod::Coverage),
  perl(Test::Spelling) and aspell-en for the release tests
- Drop redundant BR: perl(Pod::Coverage)
- Run the release tests unless we're bootstrapping
- Drop support for old distributions prior to FC-3
  - Don't need to define %%{perl_vendorlib}
  - Don't need to run test suite with LC_ALL=C

* Thu Oct  6 2011 Paul Howarth <paul@city-fan.org> - 0.31-5
- Fix dist tag for CentOS 6 and Scientific Linux

* Tue Jul  5 2011 Paul Howarth <paul@city-fan.org> - 0.31-4
- Rebuild for perl 5.14.1 in Rawhide
- Nobody else likes macros for commands

* Mon Oct 11 2010 Paul Howarth <paul@city-fan.org> - 0.31-1
- Update to 0.31
  - Added a bunch of folk to the acknowledgements
  - Added some clarifying documentation to respond to CPAN RT#59293
  - Marked a test that was failing under T::B 2.0 until we figure out
    whether it should pass or not (see http://is.gd/fNOFb)
  - Added dates to changes file, as far as we can from backpan et al
  - Fix for DB::args bug
  - Fix for bizarre-copy bug

* Wed Jun 23 2010 Paul Howarth <paul@city-fan.org> - 0.29-3
- Rebuild for perl 5.12.1 in Rawhide

* Sun May 30 2010 Paul Howarth <paul@city-fan.org> - 0.29-2
- Fix dist tag for RHEL-6 Beta

* Tue Jan 12 2010 Paul Howarth <paul@city-fan.org> - 0.29-1
- Update to 0.29 (fix code with Sub::Uplevel)
- Dist tag for Rawhide no longer needs special-casing

* Wed Sep 30 2009 Paul Howarth <paul@city-fan.org> - 0.27-3
- Define RPM macros in global scope

* Thu Nov 13 2008 Paul Howarth <paul@city-fan.org> 0.27-2
- Tweak dist tag macros to work on current Rawhide with three-part releasenum
- Run tests in "C" locale to avoid Module::Build's inability to find perl
  in the test suite on older distributions

* Mon Feb 18 2008 Paul Howarth <paul@city-fan.org> - 0.27-1
- Update to 0.27

* Tue Dec 11 2007 Paul Howarth <paul@city-fan.org> - 0.26-1
- Update to 0.26
- Clarify license as GPL version 1 or later, or Artistic (i.e. same as perl)

* Fri Feb 16 2007 Paul Howarth <paul@city-fan.org> - 0.25-1
- Update to 0.25
- Fix dist tag for FC7 onwards

* Tue Oct 10 2006 Paul Howarth <paul@city-fan.org> - 0.24-1
- Update to 0.24

* Mon Oct  9 2006 Paul Howarth <paul@city-fan.org> - 0.23-1
- Update to 0.23

* Fri Sep  1 2006 Paul Howarth <paul@city-fan.org> - 0.22-1
- Update to 0.22
- Simplify distribution-detection code
- Remove %%__perl_version macro, used only once
- Remove buildroot unconditionally in %%clean and %%install
- Use search.cpan.org download URL
- Buildreq perl(Sub::Uplevel) ≥ 0.13

* Fri Aug 26 2005 Paul Howarth <paul@city-fan.org> - 0.21-2
- Import from Fedora Extras

* Tue Jun  7 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.21-1
- Update to 0.21

* Thu May 12 2005 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.20-4
- Add dist tag

* Sat Apr 16 2005 Ville Skyttä <ville.skytta at iki.fi> - 0.20-3
- Avoid .packlist creation with Module::Build ≥ 0.2609
- Trust that %%{perl_vendorlib} is defined

* Wed Apr  6 2005 Michael Schwendt <mschwendt[AT]users.sf.net> - 0.20-2
- Rebuilt

* Fri Nov  5 2004 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0.20-1
- Update to 0.20

* Sun Jul 04 2004 Jose Pedro Oliveira <jpo at di.uminho.pt> - 0:0.15-0.fdr.1
- First build
